@@ -7,6 +7,7 @@ import argparse
 import numbers
 import easydict
 import yaml
+import copy
 from . import file_utils
 
 
@@ -66,24 +67,27 @@ def parser_config_file(config: easydict.EasyDict, config_file: str, cfg_updata:
     return cfg
 
 
-def parser_config_name(config: dict, key="", join="_"):
+def parser_config_name(config: dict or str, key="", join="_"):
     """
     :param config: config
     :param key:
     :param join:拼接方式，为空返回list
     :return: List or String
     """
-    cfg = config.copy()
-    if key:
-        cfg = config[key].copy()
-    if isinstance(cfg, dict):
-        cfg = list(cfg.keys())
-    if not isinstance(cfg, list):
-        cfg = [cfg]
-    assert isinstance(cfg, list)
-    cfg = [str(c) for c in cfg if c]
-    if join:
-        cfg = "{}".format(join).join(cfg)
+    if isinstance(config, dict) or isinstance(config, easydict.EasyDict):
+        cfg = copy.deepcopy(config)
+        if key:
+            cfg = config[key].copy()
+        if isinstance(cfg, dict):
+            cfg = list(cfg.keys())
+        if not isinstance(cfg, list):
+            cfg = [cfg]
+        assert isinstance(cfg, list)
+        cfg = [str(c) for c in cfg if c]
+        if join:
+            cfg = "{}".format(join).join(cfg)
+    else:
+        cfg = config
     return cfg
 
 
